@@ -21,6 +21,7 @@ Example:
     >>> print cfg['foo-ext'].special
     1
     >>> cfg.foo.newopt = 'hi!'
+    >>> cfg.baz.enabled = 0
 
     >>> print cfg
     # configure foo-application
@@ -30,6 +31,9 @@ Example:
     newopt = hi!
     [foo-ext]
     special = 1
+    <BLANKLINE>
+    [baz]
+    enabled = 0
 
 """
 
@@ -158,6 +162,14 @@ class OptionLine(LineType):
     parse = classmethod(parse)
 
 
+def change_comment_syntax(comment_chars='%;#', allow_rem=False):
+    comment_chars = re.sub(r'([\]\-\^])', r'\\\1', comment_chars)
+    regex = r'^(?P<csep>[%s]' % comment_chars
+    if allow_rem:
+        regex += '|[rR][eE][mM]'
+    regex += r')(?P<comment>.*)$'
+    CommentLine.regex = re.compile(regex)
+
 class CommentLine(LineType):
     regex = re.compile(r'^(?P<csep>[;#]|[rR][eE][mM])'
                        r'(?P<comment>.*)$')
@@ -339,7 +351,7 @@ class INISection(config.ConfigNamespace):
             value = re.sub('\n+', '\n', value)
         return value
 
-    def __getitem__(self, key):
+    def _getitem(self, key):
         if key == '__name__':
             return self._lines[-1].name
         if self._optionxform: key = self._optionxform(key)
@@ -404,7 +416,7 @@ class INISection(config.ConfigNamespace):
 
 
 def make_comment(line):
-    return CommentLine(line.rstrip())
+    return CommentLine(line.rstrip('\n'))
 
 
 def readline_iterator(f):
@@ -461,7 +473,7 @@ class INIConfig(config.ConfigNamespace):
     _optionxform = _make_xform_property('_optionxform', 'optionxform')
     _sectionxform = _make_xform_property('_sectionxform', 'optionxform')
 
-    def __getitem__(self, key):
+    def _getitem(self, key):
         if key == DEFAULTSECT:
             return self._defaults
         if self._sectionxform: key = self._sectionxform(key)
@@ -578,11 +590,9 @@ class INIConfig(config.ConfigNamespace):
 
             if isinstance(lineobj, OptionLine):
                 if pending_lines:
-                    cur_option.extend(pending_lines)
+                    cur_section.extend(pending_lines)
                     pending_lines = []
-                    if pending_empty_lines:
-                        optobj._compat_skip_empty_lines.add(cur_option_name)
-                        pending_empty_lines = False
+                    pending_empty_lines = False
                 cur_option = LineContainer(lineobj)
                 cur_section.add(cur_option)
                 if self._optionxform:
@@ -630,3 +640,4 @@ class INIConfig(config.ConfigNamespace):
         if exc:
             raise exc
 
+
